@@ -19,10 +19,10 @@
 #include <string>
 #include <ostream>
 
-/* std::string or Glib::ustring in function prototypes in libxml++?
+/* std::string or ustring in function prototypes in libxml++?
  *
  * If it's propagated to a libxml2 function that takes a xmlChar*, it's
- * UTF-8 encoded, and Glib::ustring is the right choice.
+ * UTF-8 encoded, and ustring is the right choice.
  *
  * If it's propagated to a libxml2 function that takes a char*, it's not
  * necessarily UTF-8 encoded, and std::string is usually the right choice.
@@ -62,25 +62,24 @@ enum class XmlEntityType
 /**
  * Represents an XML document in the DOM model.
  */
-class Document : public NonCopyable
+class LIBXMLPP_API Document : public NonCopyable
 {
   //Ensure that libxml is properly initialised:
-  class LIBXMLPP_API Init
+  class Init
   {
   public:
     Init();
     ~Init() noexcept;
   };
 
-  friend LIBXMLPP_API class SaxParser;
+  friend class SaxParser;
 
 public:
   /** Create a new document.
    * @param version XML version.
    * @throws xmlpp::internal_error If memory allocation fails.
    */
-  LIBXMLPP_API
-  explicit Document(const Glib::ustring& version = "1.0");
+  explicit Document(const ustring& version = "1.0");
 
   /** Create a new C++ wrapper for an xmlDoc struct.
    * The created xmlpp::Document takes ownership of the xmlDoc.
@@ -88,19 +87,17 @@ public:
    * @param doc A pointer to an xmlDoc struct. Must not be <tt>nullptr</tt>.
    * @throws xmlpp::internal_error If @a doc is <tt>nullptr</tt>.
    */
-  LIBXMLPP_API explicit Document(_xmlDoc* doc);
+  explicit Document(_xmlDoc* doc);
 
-  LIBXMLPP_API ~Document() override;
+  ~Document() override;
 
   /** @return The encoding used in the source from which the document has been loaded.
    */
-  LIBXMLPP_API
-  Glib::ustring get_encoding() const;
+  ustring get_encoding() const;
 
   /** Get the internal subset of this document.
    * @returns A pointer to the DTD, or <tt>nullptr</tt> if not found.
    */
-  LIBXMLPP_API
   Dtd* get_internal_subset() const;
 
   /** Create the internal subset of this document.
@@ -109,23 +106,20 @@ public:
    * @param external_id The external (PUBLIC) ID, or an empty string.
    * @param system_id The system ID, or an empty string.
    */
-  LIBXMLPP_API
-  void set_internal_subset(const Glib::ustring& name,
-                           const Glib::ustring& external_id,
-                           const Glib::ustring& system_id);
+  void set_internal_subset(const ustring& name,
+                           const ustring& external_id,
+                           const ustring& system_id);
 
   /** Return the root node.
    * This function does @b not create a default root node if it doesn't exist.
    * @return A pointer to the root node if it exists, <tt>nullptr</tt> otherwise.
    */
-  LIBXMLPP_API
   Element* get_root_node();
 
   /** Return the root node.
    * This function does @b not create a default root node if it doesn't exist.
    * @return A pointer to the root node if it exists, <tt>nullptr</tt> otherwise.
    */
-  LIBXMLPP_API
   const Element* get_root_node() const;
 
   /** Create the root element node.
@@ -140,10 +134,9 @@ public:
    * @throws xmlpp::internal_error If memory allocation fails.
    * @throws xmlpp::exception If a new namespace node cannot be created.
    */
-  LIBXMLPP_API
-  Element* create_root_node(const Glib::ustring& name,
-                            const Glib::ustring& ns_uri = Glib::ustring(),
-                            const Glib::ustring& ns_prefix = Glib::ustring() );
+  Element* create_root_node(const ustring& name,
+                            const ustring& ns_uri = ustring(),
+                            const ustring& ns_prefix = ustring() );
 
   /** Create a root element node by importing the node from another document,
    * without affecting the source node.
@@ -155,7 +148,6 @@ public:
    * @return A pointer to the new root node
    * @throws xmlpp::exception If the node can't be copied.
    */
-  LIBXMLPP_API
   Element* create_root_node_by_import(const Node* node,
 				      bool recursive = true);
 
@@ -164,8 +156,7 @@ public:
    * @returns The new comment node.
    * @throws xmlpp::internal_error
    */
-  LIBXMLPP_API
-  CommentNode* add_comment(const Glib::ustring& content);
+  CommentNode* add_comment(const ustring& content);
 
   /** Append a new processing instruction node.
    *
@@ -176,17 +167,15 @@ public:
    * @returns The new processing instruction node.
    * @throws xmlpp::internal_error
    */
-  LIBXMLPP_API
   ProcessingInstructionNode* add_processing_instruction(
-    const Glib::ustring& name, const Glib::ustring& content);
+    const ustring& name, const ustring& content);
 
   /** Write the document to a file.
    * @param filename
    * @param encoding If not provided, UTF-8 is used
    * @throws xmlpp::exception
    */
-  LIBXMLPP_API
-  void write_to_file(const std::string& filename, const Glib::ustring& encoding = Glib::ustring());
+  void write_to_file(const std::string& filename, const ustring& encoding = ustring());
 
   /** Write the document to a file.
    * The output is formatted by inserting whitespaces, which is easier to read for a human,
@@ -195,16 +184,14 @@ public:
    * @param encoding If not provided, UTF-8 is used
    * @throws xmlpp::exception
    */
-  LIBXMLPP_API
-  void write_to_file_formatted(const std::string& filename, const Glib::ustring& encoding = Glib::ustring());
+  void write_to_file_formatted(const std::string& filename, const ustring& encoding = ustring());
 
   /** Write the document to the memory.
    * @param encoding If not provided, UTF-8 is used
    * @returns The written document.
    * @throws xmlpp::exception
    */
-  LIBXMLPP_API
-  Glib::ustring write_to_string(const Glib::ustring& encoding = Glib::ustring());
+  ustring write_to_string(const ustring& encoding = ustring());
 
   /** Write the document to the memory.
    * The output is formatted by inserting whitespaces, which is easier to read for a human,
@@ -213,8 +200,7 @@ public:
    * @returns The written document.
    * @throws xmlpp::exception
    */
-  LIBXMLPP_API
-  Glib::ustring write_to_string_formatted(const Glib::ustring& encoding = Glib::ustring());
+  ustring write_to_string_formatted(const ustring& encoding = ustring());
 
   /** Write the document to a std::ostream.
    * @param output A reference to the stream in which the document will be written
@@ -224,8 +210,7 @@ public:
    * @warning This method is much less efficient than write_to_string if you want to dump the
    * document to a buffer or the standard output. Writing to a fstream is almost as fast as write_to_file
    */
-  LIBXMLPP_API
-  void write_to_stream(std::ostream& output, const Glib::ustring& encoding = Glib::ustring());
+  void write_to_stream(std::ostream& output, const ustring& encoding = ustring());
 
   /** Write the document to a std::ostream.
    * The output is formatted by inserting whitespaces, which is easier to read for a human,
@@ -236,8 +221,7 @@ public:
    * @throws xmlpp::internal_error
    * @warning See write_to_stream
    */
-  LIBXMLPP_API
-  void write_to_stream_formatted(std::ostream & output, const Glib::ustring& encoding = Glib::ustring());
+  void write_to_stream_formatted(std::ostream & output, const ustring& encoding = ustring());
 
   /** Add an Entity declaration to the document.
    * @param name The name of the entity that will be used in an entity reference.
@@ -248,12 +232,9 @@ public:
    * is the replacement value.
    * @throws xmlpp::internal_error
    */
-  LIBXMLPP_API
-  virtual void set_entity_declaration(const Glib::ustring& name, 
-                                      XmlEntityType type,
-                                      const Glib::ustring& publicId,
-                                      const Glib::ustring& systemId,
-                                      const Glib::ustring& content);
+  virtual void set_entity_declaration(const ustring& name, XmlEntityType type,
+                                      const ustring& publicId, const ustring& systemId,
+                                      const ustring& content);
 
   /** Perform XInclude substitution on the XML document.
    * XInclude substitution may both add and delete nodes in the document,
@@ -274,14 +255,13 @@ public:
    * @returns The number of substitutions.
    * @throws xmlpp::exception
    */
-  LIBXMLPP_API
   int process_xinclude(bool generate_xinclude_nodes = true, bool fixup_base_uris = true);
 
   ///Access the underlying libxml implementation.
-  LIBXMLPP_API _xmlDoc* cobj() noexcept;
+  _xmlDoc* cobj() noexcept;
 
   ///Access the underlying libxml implementation.
-  LIBXMLPP_API const _xmlDoc* cobj() const noexcept;
+  const _xmlDoc* cobj() const noexcept;
 
 protected:
   /** Retrieve an Entity.
@@ -289,15 +269,12 @@ protected:
    * @param name The name of the entity to get.
    * @returns A pointer to the libxml2 entity structure, or <tt>nullptr</tt> if not found.
    */
-  LIBXMLPP_API
-  _xmlEntity* get_entity(const Glib::ustring& name);
+  _xmlEntity* get_entity(const ustring& name);
 
 private:
-  LIBXMLPP_API
-  void do_write_to_file(const std::string& filename, const Glib::ustring& encoding, bool format);
-  Glib::ustring do_write_to_string(const Glib::ustring& encoding, bool format);
-  LIBXMLPP_API
-  void do_write_to_stream(std::ostream& output, const Glib::ustring& encoding, bool format);
+  void do_write_to_file(const std::string& filename, const ustring& encoding, bool format);
+  ustring do_write_to_string(const ustring& encoding, bool format);
+  void do_write_to_stream(std::ostream& output, const ustring& encoding, bool format);
 
   static Init init_;
 
