@@ -22,7 +22,7 @@
 
 #include <exception>
 #include <cstdarg> // va_list
-#include <glibmm/ustring.h>
+#include "libxml++/ustring.h"
 
 #include <libxml++config.h>
 
@@ -36,20 +36,19 @@ namespace xmlpp
 
 /** Base class for all xmlpp exceptions.
  */
-class exception : public std::exception
+class LIBXMLPP_API exception : public std::exception
 {
 public:
-  LIBXMLPP_API
-  explicit exception(const Glib::ustring& message);
-  LIBXMLPP_API ~exception() noexcept override;
+  explicit exception(const ustring& message);
+  ~exception() noexcept override;
 
-  LIBXMLPP_API const char* what() const noexcept override;
+  const char* what() const noexcept override;
 
-  LIBXMLPP_API virtual void raise() const;
-  LIBXMLPP_API virtual exception* clone() const;
+  virtual void raise() const;
+  virtual exception* clone() const;
 
 private:
-  Glib::ustring message_;
+  ustring message_;
 };
 
 /** Format an _xmlError struct into a text string, suitable for printing.
@@ -62,7 +61,7 @@ private:
  *          error (error->code == XML_ERR_OK), an empty string is returned.
  */
 LIBXMLPP_API
-Glib::ustring format_xml_error(const _xmlError* error = nullptr);
+ustring format_xml_error(const _xmlError* error = nullptr);
 
 /** Format a parser error into a text string, suitable for printing.
  *
@@ -74,7 +73,7 @@ Glib::ustring format_xml_error(const _xmlError* error = nullptr);
  *          string is returned.
  */
 LIBXMLPP_API
-Glib::ustring format_xml_parser_error(const _xmlParserCtxt* parser_context);
+ustring format_xml_parser_error(const _xmlParserCtxt* parser_context);
 
 /** Format a message from a function with C-style variadic parameters.
  *
@@ -87,7 +86,7 @@ Glib::ustring format_xml_parser_error(const _xmlParserCtxt* parser_context);
  * {
  *   va_list args;
  *   va_start(args, fmt);
- *   Glib::ustring msg = xmlpp::format_printf_message(fmt, args);
+ *   ustring msg = xmlpp::format_printf_message(fmt, args);
  *   va_end(args);
  *   // ...
  * }
@@ -96,7 +95,7 @@ Glib::ustring format_xml_parser_error(const _xmlParserCtxt* parser_context);
  * @newin{3,0}
  */
 LIBXMLPP_API
-Glib::ustring format_printf_message(const char* fmt, va_list args);
+ustring format_printf_message(const char* fmt, va_list args);
 
 } // namespace xmlpp
 
