@@ -28,24 +28,22 @@ namespace xmlpp {
  *
  * Abstract base class for DOM parser and SAX parser.
  */
-class Parser : public NonCopyable
+class LIBXMLPP_API Parser : public NonCopyable
 {
 public:
-  LIBXMLPP_API Parser();
-  LIBXMLPP_API ~Parser() override;
+  Parser();
+  ~Parser() override;
 
   using size_type = unsigned int;
 
   /** By default, the parser will not validate the XML file.
    * @param val Whether the document should be validated.
    */
-  LIBXMLPP_API
   void set_validate(bool val = true) noexcept;
 
   /** See set_validate().
    * @returns Whether the parser will validate the XML file.
    */
-  LIBXMLPP_API
   bool get_validate() const noexcept;
 
   /** Set whether the parser will automatically substitute entity references with the text of the entities' definitions.
@@ -53,13 +51,11 @@ public:
    * By default, the parser will not substitute entities, so that you do not lose the entity reference information.
    * @param val Whether entities will be substitued.
    */
-  LIBXMLPP_API
   void set_substitute_entities(bool val = true) noexcept;
 
   /** See set_substitute_entities().
    * @returns Whether entities will be substituted during parsing.
    */
-  LIBXMLPP_API
   bool get_substitute_entities() const noexcept;
 
   /** Set whether the parser will collect and throw error and warning messages.
@@ -84,7 +80,6 @@ public:
    *
    * @param val Whether messages will be collected and thrown in an exception.
    */
-  LIBXMLPP_API
   void set_throw_messages(bool val = true) noexcept;
 
   /** See set_throw_messages().
@@ -93,7 +88,6 @@ public:
    *
    * @returns Whether messages will be collected and thrown in an exception.
    */
-  LIBXMLPP_API
   bool get_throw_messages() const noexcept;
 
   /** Set whether default attribute values from the DTD shall be included in the node tree.
@@ -106,7 +100,6 @@ public:
    *
    * @param val Whether attributes with default values will be included in the node tree.
    */
-  LIBXMLPP_API
   void set_include_default_attributes(bool val = true) noexcept;
 
   /** See set_include_default_attributes().
@@ -115,13 +108,10 @@ public:
    *
    * @returns Whether attributes with default values will be included in the node tree.
    */
-  LIBXMLPP_API
   bool get_include_default_attributes() const noexcept;
 
   /** Set and/or clear parser option flags.
-   * See the libxml2 documentation,
-   * [enum xmlParserOption](https://gnome.pages.gitlab.gnome.org/libxml2/devhelp/libxml2-parser.html#xmlParserOption),
-   * for a list of parser options.
+   * See the libxml2 documentation, enum xmlParserOption, for a list of parser options.
    * This method overrides other methods that set parser options, such as set_validate(),
    * set_substitute_entities() and set_include_default_attributes(). Use set_parser_options()
    * only if no other method can set the parser options you want.
@@ -132,7 +122,6 @@ public:
    * @param clear_options Set bits correspond to flags that shall be cleared during parsing.
    *        Bits that are set in neither @a set_options nor @a clear_options are not affected.
    */
-  LIBXMLPP_API
   void set_parser_options(int set_options = 0, int clear_options = 0) noexcept;
 
   /** See set_parser_options().
@@ -143,14 +132,12 @@ public:
    * @param[out] clear_options Set bits correspond to flags that shall be cleared during parsing.
    *        Bits that are set in neither @a set_options nor @a clear_options are not affected.
    */
-  LIBXMLPP_API
   void get_parser_options(int& set_options, int& clear_options) const noexcept;
 
   /** Parse an XML document from a file.
    * @throw exception
    * @param filename The path to the file.
    */
-  LIBXMLPP_API
   virtual void parse_file(const std::string& filename) = 0;
 
   /** Parse an XML document from raw memory.
@@ -158,56 +145,40 @@ public:
    * @param contents The XML document as an array of bytes.
    * @param bytes_count The number of bytes in the @a contents array.
    */
-  LIBXMLPP_API
   virtual void parse_memory_raw(const unsigned char* contents, size_type bytes_count) = 0;
 
   /** Parse an XML document from a string.
    * @throw exception
    * @param contents The XML document as a string.
    */
-  LIBXMLPP_API
-  virtual void parse_memory(const Glib::ustring& contents) = 0;
+  virtual void parse_memory(const ustring& contents) = 0;
 
   /** Parse an XML document from a stream.
    * @throw exception
    * @param in The stream.
    */
-  LIBXMLPP_API
   virtual void parse_stream(std::istream& in) = 0;
 
   //TODO: Add stop_parser()/stop_parsing(), wrapping xmlStopParser()?
 
 protected:
-  LIBXMLPP_API
   virtual void initialize_context();
-  LIBXMLPP_API
   virtual void release_underlying();
 
-  LIBXMLPP_API
-  virtual void on_parser_error(const Glib::ustring& message);
-  LIBXMLPP_API
-  virtual void on_parser_warning(const Glib::ustring& message);
-  LIBXMLPP_API
-  virtual void on_validity_error(const Glib::ustring& message);
-  LIBXMLPP_API
-  virtual void on_validity_warning(const Glib::ustring& message);
+  virtual void on_parser_error(const ustring& message);
+  virtual void on_parser_warning(const ustring& message);
+  virtual void on_validity_error(const ustring& message);
+  virtual void on_validity_warning(const ustring& message);
 
   /// To be called in an exception handler.
-  LIBXMLPP_API
   virtual void handle_exception();
-  LIBXMLPP_API
   virtual void check_for_exception();
 
-  LIBXMLPP_API
   virtual void check_for_error_and_warning_messages();
 
-  LIBXMLPP_API
   static void callback_parser_error(void* ctx, const char* msg, ...);
-  LIBXMLPP_API
   static void callback_parser_warning(void* ctx, const char* msg, ...);
-  LIBXMLPP_API
   static void callback_validity_error(void* ctx, const char* msg, ...);
-  LIBXMLPP_API
   static void callback_validity_warning(void* ctx, const char* msg, ...);
 
   enum class MsgType
@@ -218,7 +189,6 @@ protected:
     ValidityWarning
   };
 
-  LIBXMLPP_API
   static void callback_error_or_warning(MsgType msg_type, void* ctx,
                                         const char* msg, va_list var_args);
 
