@@ -9,7 +9,6 @@
 
 #include <libxml++/parsers/parser.h>
 
-#include <list>
 #include <deque>
 #include <memory>
 #include "libxml++/document.h"
@@ -25,13 +24,14 @@ namespace xmlpp {
 
 /** SAX XML parser.
  * Derive your own class and override the on_*() methods.
+ * SAX = Simple API for XML
  *
  * In a system that does not support std::exception_ptr: If an overridden on_*()
  * method throws an exception which is not derived from xmlpp::exception,
  * that exception is replaced by a xmlpp::exception before it is propagated
  * out of the parse method, such as parse_file().
  */
-class SaxParser : public Parser
+class LIBXMLPP_API SaxParser : public Parser
 {
 public:
   /**
@@ -40,31 +40,31 @@ public:
    */
   struct Attribute
   {
-    Glib::ustring name;
-    Glib::ustring value;
+    ustring name;
+    ustring value;
 
-    Attribute(Glib::ustring const & n, Glib::ustring const & v)
+    Attribute(ustring const & n, ustring const & v)
       : name(n), value(v)
       {
       }
   };
 
-  typedef std::deque< Attribute > AttributeList;
+  using AttributeList = std::deque<Attribute>;
 
   /** This functor is a helper to find an attribute by name in an
    * AttributeList using the standard algorithm std::find_if
-   * 
+   *
    * Example:@n
    * <code>
-   *   Glib::ustring name = "foo";@n
+   *   ustring name = "foo";@n
    *   AttributeList::const_iterator attribute = std::find_if(attributes.begin(), attributes.end(), AttributeHasName(name));
    * </code>
    */
   struct AttributeHasName
   {
-    Glib::ustring const & name;
+    ustring const & name;
 
-    AttributeHasName(Glib::ustring const & n)
+    AttributeHasName(ustring const & n)
       : name(n)
       {
       }
@@ -74,8 +74,8 @@ public:
       return attribute.name == name;
     }
   };
-  
-  /** 
+
+  /**
    * @param use_get_entity Set this to true if you will override on_get_entity().
    * In theory, if you do not override on_get_entity() the parser should behave exactly the same
    * whether you use true or false here. But the default implementation of on_get_entity(), needed
@@ -91,7 +91,7 @@ public:
    * @throws xmlpp::parse_error
    * @throws xmlpp::validity_error
    */
-  void parse_file(const Glib::ustring& filename) override;
+  void parse_file(const std::string& filename) override;
 
   /** Parse an XML document from a string.
    * @param contents The XML document as a string.
@@ -99,7 +99,7 @@ public:
    * @throws xmlpp::parse_error
    * @throws xmlpp::validity_error
    */
-  void parse_memory(const Glib::ustring& contents) override;
+  void parse_memory(const ustring& contents) override;
 
   /** Parse an XML document from raw memory.
    * @param contents The XML document as an array of bytes.
@@ -108,7 +108,7 @@ public:
    * @throws xmlpp::parse_error
    * @throws xmlpp::validity_error
    */
-  void parse_memory_raw(const unsigned char* contents, size_type bytes_count);
+  void parse_memory_raw(const unsigned char* contents, size_type bytes_count) override;
 
   /** Parse an XML document from a stream.
    * @param in The stream.
@@ -117,15 +117,14 @@ public:
    * @throws xmlpp::validity_error
    */
   void parse_stream(std::istream& in) override;
-  
-  //TODO: Remove virtual when we can break ABI?
+
   /** Parse a chunk of data.
    *
    * This lets you pass a document in small chunks, e.g. from a network
    * connection. The on_* virtual functions are called each time the chunks
    * provide enough information to advance the parser.
    *
-   * The first call to parse_chunk will setup the parser. When the last chunk
+   * The first call to parse_chunk() will setup the parser. When the last chunk
    * has been parsed, call finish_chunk_parsing() to finish the parse.
    *
    * @param chunk The next piece of the XML document.
@@ -133,7 +132,7 @@ public:
    * @throws xmlpp::parse_error
    * @throws xmlpp::validity_error
    */
-  virtual void parse_chunk(const Glib::ustring& chunk);
+  void parse_chunk(const ustring& chunk);
 
   /** Parse a chunk of data.
    *
@@ -143,7 +142,7 @@ public:
    * connection. The on_* virtual functions are called each time the chunks
    * provide enough information to advance the parser.
    *
-   * The first call to parse_chunk will setup the parser. When the last chunk
+   * The first call to parse_chunk_raw() will setup the parser. When the last chunk
    * has been parsed, call finish_chunk_parsing() to finish the parse.
    *
    * @param contents The next piece of the XML document as an array of bytes.
@@ -154,36 +153,35 @@ public:
    */
   void parse_chunk_raw(const unsigned char* contents, size_type bytes_count);
 
-  //TODO: Remove virtual when we can break ABI?
   /** Finish a chunk-wise parse.
    *
-   * Call this after the last call to parse_chunk(). Don't use this function with
-   * the other parsing methods.
+   * Call this after the last call to parse_chunk() or parse_chunk_raw().
+   * Don't use this function with the other parsing methods.
    * @throws xmlpp::internal_error
    * @throws xmlpp::parse_error
    * @throws xmlpp::validity_error
    */
-  virtual void finish_chunk_parsing();
+  void finish_chunk_parsing();
 
 protected:
-        
+
   virtual void on_start_document();
   virtual void on_end_document();
-  virtual void on_start_element(const Glib::ustring& name, const AttributeList& attributes);
-  virtual void on_end_element(const Glib::ustring& name);
-  virtual void on_characters(const Glib::ustring& characters);
-  virtual void on_comment(const Glib::ustring& text);
-  virtual void on_warning(const Glib::ustring& text);
-  virtual void on_error(const Glib::ustring& text);
+  virtual void on_start_element(const ustring& name, const AttributeList& attributes);
+  virtual void on_end_element(const ustring& name);
+  virtual void on_characters(const ustring& characters);
+  virtual void on_comment(const ustring& text);
+  virtual void on_warning(const ustring& text);
+  virtual void on_error(const ustring& text);
 
   /** @throws xmlpp::parse_error
    */
-  virtual void on_fatal_error(const Glib::ustring& text);
-  virtual void on_cdata_block(const Glib::ustring& text);
+  virtual void on_fatal_error(const ustring& text);
+  virtual void on_cdata_block(const ustring& text);
 
   /** Override this to receive information about the document's DTD and any entity declarations.
    */
-  virtual void on_internal_subset(const Glib::ustring& name, const Glib::ustring& publicId, const Glib::ustring& systemId);
+  virtual void on_internal_subset(const ustring& name, const ustring& publicId, const ustring& systemId);
 
   /** Override this method to resolve entities references in your derived parser, instead of using the default entity resolution,
    * or to be informed when entity references are encountered.
@@ -205,7 +203,7 @@ protected:
    *          You must include libxml/parser.h in order to use this C struct.
    * This instance will not be freed by the caller.
    */
-  virtual _xmlEntity* on_get_entity(const Glib::ustring& name);
+  virtual _xmlEntity* on_get_entity(const ustring& name);
 
   /** Override this to receive information about every entity declaration.
    * If you override this function, and you want normal entity substitution to work, then you must call the base class in your override.
@@ -213,19 +211,19 @@ protected:
    * This would be useful when overriding on_get_entity().
    * @throws xmlpp::internal_error
    */
-  virtual void on_entity_declaration(const Glib::ustring& name, XmlEntityType type, const Glib::ustring& publicId, const Glib::ustring& systemId, const Glib::ustring& content);
+  virtual void on_entity_declaration(const ustring& name, XmlEntityType type, const ustring& publicId, const ustring& systemId, const ustring& content);
 
   void release_underlying() override;
-  
+  void initialize_context() override;
+
 private:
-  //TODO: Remove the virtual when we can break ABI?
-  virtual void parse();
-  
-  std::auto_ptr<_xmlSAXHandler> sax_handler_;
+  void parse();
+
+  std::unique_ptr<_xmlSAXHandler> sax_handler_;
 
   // A separate xmlpp::Document that is just used for entity resolution,
   // and never seen in the API:
-  xmlpp::Document entity_resolver_doc_;
+  std::unique_ptr<Document> entity_resolver_doc_;
 
   friend struct SaxParserCallback;
 };
