@@ -24,25 +24,20 @@
 #include <libxml++/validators/schemavalidatorbase.h>
 #include <memory> // std::unique_ptr
 
-namespace Glib
-{
-class ustring;
-}
-
 namespace xmlpp
 {
-class Document;
-class RelaxNGSchema;
+class LIBXMLPP_API Document;
+class LIBXMLPP_API RelaxNGSchema;
 
 /** RelaxNG schema validator.
  * RelaxNG = REgular LAnguage for XML Next Generation
  *
  * @newin{2,38}
  */
-class RelaxNGValidator : public SchemaValidatorBase
+class LIBXMLPP_API RelaxNGValidator : public SchemaValidatorBase
 {
 public:
-  LIBXMLPP_API RelaxNGValidator();
+  RelaxNGValidator();
 
   /** Create a validator and parse a schema definition file.
    * The schema must be defined with XML syntax (.rng file). The compact syntax
@@ -50,14 +45,12 @@ public:
    * @param filename The URL of the schema.
    * @throws xmlpp::parse_error
    */
-  LIBXMLPP_API
   explicit RelaxNGValidator(const std::string& filename);
 
   /** Create a validator and parse a schema definition document.
    * @param document A preparsed document tree, containing the schema definition.
    * @throws xmlpp::parse_error
    */
-  LIBXMLPP_API
   explicit RelaxNGValidator(const Document* document);
 
   /** Create a validator.
@@ -69,10 +62,9 @@ public:
    *        validator keeps a pointer to it. The caller is responsible for
    *        deleting the schema when it's no longer needed.
    */
-  LIBXMLPP_API
   explicit RelaxNGValidator(RelaxNGSchema* schema, bool take_ownership);
 
-  LIBXMLPP_API ~RelaxNGValidator() override;
+  ~RelaxNGValidator() override;
 
   /** Parse a schema definition file.
    * The schema must be defined with XML syntax (.rng file). The compact syntax
@@ -83,7 +75,6 @@ public:
    * @param filename The URL of the schema.
    * @throws xmlpp::parse_error
    */
-  LIBXMLPP_API
   void parse_file(const std::string& filename) override;
 
   /** Parse a schema definition from a string.
@@ -94,8 +85,7 @@ public:
    * @param contents The schema definition as a string.
    * @throws xmlpp::parse_error
    */
-  LIBXMLPP_API
-  void parse_memory(const Glib::ustring& contents) override;
+  void parse_memory(const ustring& contents) override;
 
   /** Parse a schema definition from a document.
    * If the validator already contains a schema, that schema is released
@@ -103,7 +93,6 @@ public:
    * @param document A preparsed document tree, containing the schema definition.
    * @throws xmlpp::parse_error
    */
-  LIBXMLPP_API
   void parse_document(const Document* document) override;
 
   /** Set a schema.
@@ -117,7 +106,6 @@ public:
    *        validator keeps a pointer to it. The caller is responsible for
    *        deleting the schema when it's no longer needed.
    */
-  LIBXMLPP_API
   void set_schema(RelaxNGSchema* schema, bool take_ownership);
 
   /** Test whether a schema has been parsed.
@@ -127,19 +115,16 @@ public:
    *   do_something();
    * @endcode
    */
-  LIBXMLPP_API
   explicit operator bool() const noexcept override;
 
   /** Get the schema.
    * @returns A pointer to the schema, or <tt>nullptr</tt>.
    */
-  LIBXMLPP_API
   RelaxNGSchema* get_schema() noexcept;
 
   /** Get the schema.
    * @returns A pointer to the schema, or <tt>nullptr</tt>.
    */
-  LIBXMLPP_API
   const RelaxNGSchema* get_schema() const noexcept;
 
   /** Validate a document, using a previously parsed schema.
@@ -147,7 +132,6 @@ public:
    * @throws xmlpp::internal_error
    * @throws xmlpp::validity_error
    */
-  LIBXMLPP_API
   void validate(const Document* document) override;
 
   /** Validate an XML file, using a previously parsed schema.
@@ -156,13 +140,10 @@ public:
    * @throws xmlpp::parse_error
    * @throws xmlpp::validity_error
    */
-  LIBXMLPP_API
   void validate(const std::string& filename) override;
 
 protected:
-  LIBXMLPP_API
   void initialize_context() override;
-  LIBXMLPP_API
   void release_underlying() override;
 
 private:
